---
title: <span class="badge builder"></span> NodesQuery
---
# <span class="badge builder"></span> NodesQuery

## Constructor

```python
NodesQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> testdata.NodesQuery
```

### <span class="badge object-method"></span> count

```python
def count(count: int) -> typing.Self
```

### <span class="badge object-method"></span> type_val

```python
def type_val(type_val: typing.Literal["random", "response", "random edges"]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [NodesQuery](./object-NodesQuery.md)
